# json-schema-to-class [![Build Status](https://travis-ci.com/FebruaryBreeze/json-schema-to-class.svg?branch=master)](https://travis-ci.com/FebruaryBreeze/json-schema-to-class) [![codecov](https://codecov.io/gh/FebruaryBreeze/json-schema-to-class/branch/master/graph/badge.svg)](https://codecov.io/gh/FebruaryBreeze/json-schema-to-class)

Convert JSON Schema into Python Class

## Installation

Need Python 3.6+.

```bash
pip install json-schema-to-class
```

## Usage

```bash
json-schema-to-class tests/test.schema.json -o tests/schema_build.py
```
